@@ -10,6 +10,7 @@
 # EnvVar OQS_ALGS_ENABLED: If set, defines OQS algs to be enabled, e.g., "STD"
 # EnvVar OPENSSL_INSTALL: If set, defines (binary) OpenSSL installation to use
 # EnvVar OPENSSL_BRANCH: Defines branch/release of openssl; if set, forces source-build of OpenSSL3
+#        Setting this to feature/dtls-1.3 enables build&test of all PQ algs using DTLS1.3 feature branch
 # EnvVar liboqs_DIR: If set, needs to point to a directory where liboqs has been installed to
 
 if [[ "$OSTYPE" == "darwin"* ]]; then
@@ -40,7 +41,7 @@ else
 fi
 
 if [ -z "$OQS_LIBJADE_BUILD"]; then
-   export DOQS_LIBJADE_BUILD="-DOQS_LIBJADE_BUILD=ON"
+   export DOQS_LIBJADE_BUILD="-DOQS_LIBJADE_BUILD=OFF"
 else
    export DOQS_LIBJADE_BUILD="-DOQS_LIBJADE_BUILD=$OQS_LIBJADE_BUILD"
 fi
